@@ -1,7 +1,7 @@
 """
 ##
 ## Copyright (C) 2007 Trolltech ASA. All rights reserved.
-## Copyright (C) 2010-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+## Copyright (C) 2010-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 ##
 ## This file is part of the Qt Concurrent project on Trolltech Labs.
 ##
@@ -10,27 +10,37 @@
 ## and appearing in the file LICENSE.GPL included in the packaging of
 ## this file.  Please review the following information to ensure GNU
 ## General Public Licensing requirements will be met:
-## http://www.trolltech.com/products/qt/opensource.html
+## https://www.qt.io/download-open-source
 ##
 ## If you are unsure which license is appropriate for your use, please
 ## review the following information:
-## http://www.trolltech.com/products/qt/licensing.html or contact the
-## sales department at sales@trolltech.com.
+## https://www.qt.io/licensing/ or contact the
+## sales department at https://www.qt.io/contact-us/sales-contact-request/?hsLang=en
 ##
 ## This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ## WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 ##
 #############################################################################
+
+There are several variations of python ports for this script floating
+around, it seemed easier to me to maintain one for myself
 """
 
 import sip
-from qt import QObject, Qt, QVariant, QAbstractItemModel, QModelIndex, \
-    QPersistentModelIndex
+from qt import QObject, Qt, QAbstractItemModel, QModelIndex
+from qt import QPersistentModelIndex, QFont, QColor, QSize
+from common import isAlive
 
 # pylint: skip-file
 
+def isValid(variant):
+    return (variant is not None)
+
+
 class ModelTest(QObject):
+
     """tests a model"""
+
     def __init__(self, _model, parent):
         """
         Connect to all of the models signals, Whenever anything happens recheck everything.
@@ -59,8 +69,8 @@ class ModelTest(QObject):
         self.model.rowsRemoved.connect(self.runAllTests)
 
         # Special checks for inserting/removing
-        self.model.layoutAboutToBeChanged.connect(self.layoutAboutToBeChanged )
-        self.model.layoutChanged.connect(self.layoutChanged )
+        self.model.layoutAboutToBeChanged.connect(self.layoutAboutToBeChanged)
+        self.model.layoutChanged.connect(self.layoutChanged)
         self.model.rowsAboutToBeInserted.connect(self.rowsAboutToBeInserted)
         self.model.rowsAboutToBeRemoved.connect(self.rowsAboutToBeRemoved)
         self.model.rowsInserted.connect(self.rowsInserted)
@@ -75,28 +85,28 @@ class ModelTest(QObject):
         assert(self.model.buddy(QModelIndex()) == QModelIndex())
         self.model.canFetchMore(QModelIndex())
         assert(self.model.columnCount(QModelIndex()) >= 0)
-        assert(self.model.data(QModelIndex(), Qt.DisplayRole) == QVariant())
+        assert(self.model.data(QModelIndex(), Qt.DisplayRole) is None)
         self.fetchingMore = True
         self.model.fetchMore(QModelIndex())
         self.fetchingMore = False
         flags = self.model.flags(QModelIndex())
-        assert( int(flags & Qt.ItemIsEnabled) == Qt.ItemIsEnabled or \
-               int(flags & Qt.ItemIsEnabled ) == 0 )
+        assert(int(flags & Qt.ItemIsEnabled) == Qt.ItemIsEnabled or
+               int(flags & Qt.ItemIsEnabled) == 0)
         self.model.hasChildren(QModelIndex())
         self.model.hasIndex(0, 0)
         self.model.headerData(0, Qt.Horizontal, Qt.DisplayRole)
         self.model.index(0, 0, QModelIndex())
         self.model.itemData(QModelIndex())
-        cache = QVariant()
+        cache = None
         self.model.match(QModelIndex(), -1, cache)
         self.model.mimeTypes()
         assert(self.model.parent(QModelIndex()) == QModelIndex())
         assert(self.model.rowCount(QModelIndex()) >= 0)
-        variant = QVariant()
+        variant = None
         self.model.setData(QModelIndex(), variant, -1)
-        self.model.setHeaderData(-1, Qt.Horizontal, QVariant())
-        self.model.setHeaderData(0, Qt.Horizontal, QVariant())
-        self.model.setHeaderData(999999, Qt.Horizontal, QVariant())
+        self.model.setHeaderData(-1, Qt.Horizontal, None)
+        self.model.setHeaderData(0, Qt.Horizontal, None)
+        self.model.setHeaderData(999999, Qt.Horizontal, None)
         self.model.sibling(0, 0, QModelIndex())
         self.model.span(QModelIndex())
         self.model.supportedDropActions()
@@ -112,7 +122,7 @@ class ModelTest(QObject):
         rows = self.model.rowCount(topindex)
         assert(rows >= 0)
         if rows > 0:
-            assert(self.model.hasChildren(topindex) == True )
+            assert(self.model.hasChildren(topindex))
 
         secondlvl = self.model.index(0, 0, topindex)
         if secondlvl.isValid():
@@ -120,7 +130,7 @@ class ModelTest(QObject):
             rows = self.model.rowCount(secondlvl)
             assert(rows >= 0)
             if rows > 0:
-                assert(self.model.hasChildren(secondlvl) == True)
+                assert(self.model.hasChildren(secondlvl))
 
         # The self.models rowCount() is tested more extensively in checkChildren,
         # but this catches the big mistakes
@@ -135,7 +145,7 @@ class ModelTest(QObject):
 
         # check a column count where parent is valid
         childidx = self.model.index(0, 0, topidx)
-        if childidx.isValid() :
+        if childidx.isValid():
             assert(self.model.columnCount(childidx) >= 0)
 
         # columnCount() is tested more extensively in checkChildren,
@@ -155,10 +165,10 @@ class ModelTest(QObject):
 
         # check out of bounds
         assert(self.model.hasIndex(rows, cols) == False)
-        assert(self.model.hasIndex(rows+1, cols+1) == False)
+        assert(self.model.hasIndex(rows + 1, cols + 1) == False)
 
         if rows > 0:
-            assert(self.model.hasIndex(0, 0) == True)
+            assert(self.model.hasIndex(0, 0))
 
         # hasIndex() is tested more extensively in checkChildren()
         # but this catches the big mistakes
@@ -180,12 +190,12 @@ class ModelTest(QObject):
 
         # Catch off by one errors
         assert(self.model.index(rows, cols, QModelIndex()) == QModelIndex())
-        assert(self.model.index(0, 0, QModelIndex()).isValid() == True)
+        assert(self.model.index(0, 0, QModelIndex()).isValid())
 
         # Make sure that the same index is *always* returned
         idx1 = self.model.index(0, 0, QModelIndex())
         idx2 = self.model.index(0, 0, QModelIndex())
-        assert(idx1==idx2)
+        assert(idx1 == idx2)
 
         # index() is tested more extensively in checkChildren()
         # but this catches the big mistakes
@@ -213,7 +223,7 @@ class ModelTest(QObject):
 
         # Common error test #2, make sure that a second level index has a parent
         # that is the first level index
-        if self.model.rowCount(topidx) > 0 :
+        if self.model.rowCount(topidx) > 0:
             childidx = self.model.index(0, 0, topidx)
             assert(self.model.parent(childidx) == topidx)
 
@@ -230,68 +240,66 @@ class ModelTest(QObject):
         # parent's children correctly specify their parent
         self.checkChildren(QModelIndex())
 
+    def testRoleDataType(self, role, expectedType):
+        """Tests implementation if model.data() for role"""
+        model = self.model
+        result = model.data(model.index(0, 0, QModelIndex()), role)
+        if result is not None and not isinstance(result, expectedType):
+            raise Exception('returned data type is {}, should be {}'.format(
+                type(result), expectedType))
+
+    def testRoleDataValues(self, role, asserter):
+        """Tests implementation if model.data() for role.
+        asserter is a function returning True or False"""
+        model = self.model
+        result = model.data(model.index(0, 0, QModelIndex()), role)
+        if result is not None and not asserter(result):
+            raise Exception('returned value {} is wrong')
+
     def data(self):
         """
         Tests self.model's implementation of QAbstractItemModel::data()
         """
         # Invalid index should return an invalid qvariant
-        assert( not self.model.data(QModelIndex(), Qt.DisplayRole).isValid())
+        assert not isValid(self.model.data(QModelIndex(), Qt.DisplayRole))
 
         if self.model.rowCount(QModelIndex()) == 0:
             return
 
-        # A valid index should have a valid QVariant data
-        assert( self.model.index(0, 0, QModelIndex()).isValid())
+        # A valid index should have a valid data
+        assert isValid(self.model.index(0, 0, QModelIndex()))
 
         # shouldn't be able to set data on an invalid index
-        assert( self.model.setData( QModelIndex(), QVariant("foo"), Qt.DisplayRole) == False)
+        assert(
+            self.model.setData(QModelIndex(),
+                               "foo",
+                               Qt.DisplayRole) == False)
 
         # General Purpose roles that should return a QString
-        variant = self.model.data(self.model.index(0, 0, QModelIndex()), Qt.ToolTipRole)
-        if variant.isValid():
-            assert( variant.canConvert( QVariant.String ) )
-        variant = self.model.data(self.model.index(0, 0, QModelIndex()), Qt.StatusTipRole)
-        if variant.isValid():
-            assert( variant.canConvert( QVariant.String ) )
-        variant = self.model.data(self.model.index(0, 0, QModelIndex()), Qt.WhatsThisRole)
-        if variant.isValid():
-            assert( variant.canConvert( QVariant.String ) )
-
-        # General Purpose roles that should return a QSize
-        variant = self.model.data(self.model.index(0, 0, QModelIndex()), Qt.SizeHintRole)
-        if variant.isValid():
-            assert( variant.canConvert( QVariant.Size ) )
-
-        # General Purpose roles that should return a QFont
-        variant = self.model.data(self.model.index(0, 0, QModelIndex()), Qt.FontRole)
-        if variant.isValid():
-            assert( variant.canConvert( QVariant.Font ) )
+        self.testRoleDataType(Qt.ToolTipRole, str)
+        self.testRoleDataType(Qt.StatusTipRole, str)
+        self.testRoleDataType(Qt.WhatsThisRole, str)
+        self.testRoleDataType(Qt.SizeHintRole, QSize)
+        self.testRoleDataType(Qt.FontRole, QFont)
+        self.testRoleDataType(Qt.ForegroundRole, QColor)
+        self.testRoleDataType(Qt.BackgroundColorRole, QColor)
+        self.testRoleDataType(Qt.TextColorRole, QColor)
 
         # Check that the alignment is one we know about
-        variant = self.model.data(self.model.index(0, 0, QModelIndex()), Qt.TextAlignmentRole)
-        if variant.isValid():
-            alignment = variant.toInt()[0]
-            assert( alignment == (alignment & int(Qt.AlignHorizontal_Mask | Qt.AlignVertical_Mask)))
+        self.testRoleDataValues(
+            Qt.TextAlignmentRole,
+            lambda x: x == (x & int(Qt.AlignHorizontal_Mask | Qt.AlignVertical_Mask)))
 
         # General Purpose roles that should return a QColor
-        variant = self.model.data(self.model.index(0, 0, QModelIndex()), Qt.BackgroundColorRole)
-        if variant.isValid():
-            assert( variant.canConvert( QVariant.Color ) )
-        variant = self.model.data(self.model.index(0, 0, QModelIndex()), Qt.TextColorRole)
-        if variant.isValid():
-            assert( variant.canConvert( QVariant.Color ) )
-
         # Check that the "check state" is one we know about.
-        variant = self.model.data(self.model.index(0, 0, QModelIndex()), Qt.CheckStateRole)
-        if variant.isValid():
-            state = variant.toInt()[0]
-            assert( state == Qt.Unchecked or
-                state == Qt.PartiallyChecked or
-                state == Qt.Checked )
-
+        self.testRoleDataValues(
+            Qt.CheckStateRole,
+            lambda x: x in (Qt.Unchecked, Qt.PartiallyChecked, Qt.Checked))
 
     def runAllTests(self):
         """run all tests after the model changed"""
+        if not isAlive(self):
+            return
         if self.fetchingMore:
             return
         self.nonDestructiveBasicTest()
@@ -309,7 +317,7 @@ class ModelTest(QObject):
         item = {}
         item['parent'] = parent
         item['oldSize'] = self.model.rowCount(parent)
-        item['last'] = self.model.data(self.model.index(start-1, 0, parent))
+        item['last'] = self.model.data(self.model.index(start - 1, 0, parent))
         item['next'] = self.model.data(self.model.index(start, 0, parent))
         self.insert.append(item)
 
@@ -319,16 +327,20 @@ class ModelTest(QObject):
         """
         item = self.insert.pop()
         assert(item['parent'] == parent)
-        assert(item['oldSize'] + (end - start + 1) == self.model.rowCount(parent))
-        assert(item['last'] == self.model.data(self.model.index(start-1, 0, item['parent'])))
+        assert(item['oldSize'] + (end - start + 1)
+               == self.model.rowCount(parent))
+        assert(item['last'] == self.model.data(
+            self.model.index(start - 1, 0, item['parent'])))
 
         # if item['next'] != self.model.data(self.model.index(end+1, 0, item['parent'])):
         #   qDebug << start << end
         #   for i in range(0, self.model.rowCount(QModelIndex())):
         #       qDebug << self.model.index(i, 0).data().toString()
-        #   qDebug() << item['next'] << self.model.data(model.index(end+1, 0, item['parent']))
+        # qDebug() << item['next'] << self.model.data(model.index(end+1, 0,
+        # item['parent']))
 
-        assert(item['next'] == self.model.data(self.model.index(end+1, 0, item['parent'])))
+        assert(item['next'] == self.model.data(
+            self.model.index(end + 1, 0, item['parent'])))
 
     def rowsAboutToBeRemoved(self, parent, start, end):
         """
@@ -337,8 +349,8 @@ class ModelTest(QObject):
         item = {}
         item['parent'] = parent
         item['oldSize'] = self.model.rowCount(parent)
-        item['last'] = self.model.data(self.model.index(start-1, 0, parent))
-        item['next'] = self.model.data(self.model.index(end+1, 0, parent))
+        item['last'] = self.model.data(self.model.index(start - 1, 0, parent))
+        item['next'] = self.model.data(self.model.index(end + 1, 0, parent))
         self.remove.append(item)
 
     def rowsRemoved(self, parent, start, end):
@@ -347,26 +359,32 @@ class ModelTest(QObject):
         """
         item = self.remove.pop()
         assert(item['parent'] == parent)
-        assert(item['oldSize'] - (end - start + 1) == self.model.rowCount(parent))
-        assert(item['last'] == self.model.data(self.model.index(start-1, 0, item['parent'])))
-        assert(item['next'] == self.model.data(self.model.index(start, 0, item['parent'])))
+        assert(item['oldSize'] - (end - start + 1)
+               == self.model.rowCount(parent))
+        assert(item['last'] == self.model.data(
+            self.model.index(start - 1, 0, item['parent'])))
+        assert(item['next'] == self.model.data(
+            self.model.index(start, 0, item['parent'])))
 
     def layoutAboutToBeChanged(self):
         """
         Store what is about to be changed
         """
-        for i in range(0, max(0, min( self.model.rowCount(), 100))):
-            self.changing.append(QPersistentModelIndex( self.model.index( i, 0)))
+        for i in range(0, max(0, min(self.model.rowCount(), 100))):
+            self.changing.append(QPersistentModelIndex(self.model.index(i, 0)))
 
     def layoutChanged(self):
         """
         Confirm that what was said was going to happen actually did
         """
         for change in self.changing:
-            assert(change == self.model.index( change.row(), change.column(), change.parent()))
+            assert(
+                change == self.model.index(change.row(),
+                                           change.column(),
+                                           change.parent()))
         self.changing = []
 
-    def checkChildren(self, parent, depth = 0):
+    def checkChildren(self, parent, depth=0):
         """
         Called from parent() test.
 
@@ -386,8 +404,8 @@ class ModelTest(QObject):
         while parentIdx.isValid():
             parentIdx = parentIdx.parent()
 
-        #For self.models that are dynamically populated
-        if self.model.canFetchMore( parent ):
+        # For self.models that are dynamically populated
+        if self.model.canFetchMore(parent):
             self.fetchingMore = True
             self.model.fetchMore(parent)
             self.fetchingMore = False
@@ -399,71 +417,78 @@ class ModelTest(QObject):
             assert(self.model.hasChildren(parent))
 
         # Some further testing against rows(), columns, and hasChildren()
-        assert( rows >= 0 )
-        assert( cols >= 0 )
+        assert(rows >= 0)
+        assert(cols >= 0)
 
         if rows > 0:
-            assert(self.model.hasChildren(parent) == True)
+            assert(self.model.hasChildren(parent))
 
         # qDebug() << "parent:" << self.model.data(parent).toString() << "rows:" << rows
         #          << "columns:" << cols << "parent column:" << parent.column()
 
-        assert( self.model.hasIndex( rows+1, 0, parent) == False)
+        assert(self.model.hasIndex(rows + 1, 0, parent) == False)
         for row in range(0, rows):
             if self.model.canFetchMore(parent):
                 self.fetchingMore = True
                 self.model.fetchMore(parent)
                 self.fetchingMore = False
-            assert(self.model.hasIndex(row, cols+1, parent) == False)
+            assert(self.model.hasIndex(row, cols + 1, parent) == False)
             for column in range(0, cols):
                 assert(self.model.hasIndex(row, column, parent))
                 index = self.model.index(row, column, parent)
-                # rowCount(QModelIndex()) and columnCount(QModelIndex()) said that it existed...
-                assert(index.isValid() == True)
+                # rowCount(QModelIndex()) and columnCount(QModelIndex()) said
+                # that it existed...
+                assert(index.isValid())
 
-                # index() should always return the same index when called twice in a row
+                # index() should always return the same index when called twice
+                # in a row
                 modIdx = self.model.index(row, column, parent)
                 assert(index == modIdx)
 
-                # Make sure we get the same index if we request it twice in a row
+                # Make sure we get the same index if we request it twice in a
+                # row
                 idx1 = self.model.index(row, column, parent)
                 idx2 = self.model.index(row, column, parent)
-                assert( idx1 == idx2 )
+                assert(idx1 == idx2)
 
                 # Some basic checking on the index that is returned
                 # assert( index.model() == self.model )
                 # This raises an error that is not part of the qbzr code.
-                # see http://www.opensubscriber.com/message/pyqt@riverbankcomputing.com/10335500.html
-                assert( index.row() == row )
-                assert( index.column() == column )
+                # see
+                # https://www.riverbankcomputing.com/pipermail/pyqt/2011-February/029300.html
+                assert(index.row() == row)
+                assert(index.column() == column)
                 # While you can technically return a QVariant usually this is a sign
-                # if an bug in data() Disable if this really is ok in your self.model
-                assert( self.model.data(index, Qt.DisplayRole).isValid() == True )
+                # if an bug in data() Disable if this really is ok in your
+                # self.model
+                assert isValid(self.model.data(index, Qt.DisplayRole))
 
-                #if the next test fails here is some somewhat useful debug you play with
+                # if the next test fails here is some somewhat useful debug you play with
                 # if self.model.parent(index) != parent:
                 #   qDebug() << row << column << depth << self.model.data(index).toString()
                 #        << self.model.data(parent).toString()
                 #   qDebug() << index << parent << self.model.parent(index)
-                #   # And a view that you can even use to show the self.model
-                #   # view = QtGui.QTreeView()
-                #   # view.setself.model(model)
-                #   # view.show()
+                # And a view that you can even use to show the self.model
+                # view = QtGui.QTreeView()
+                # view.setself.model(model)
+                # view.show()
                 #
 
                 # Check that we can get back our real parent
-                parentIdx = self.model.parent( index )
-                assert( parentIdx.internalId() == parent.internalId() )
-                assert( parentIdx.row() == parent.row() )
+                parentIdx = self.model.parent(index)
+                assert(parentIdx.internalId() == parent.internalId())
+                assert(parentIdx.row() == parent.row())
 
                 # recursively go down the children
                 if self.model.hasChildren(index) and depth < 10:
-                    # qDebug() << row << column << "hasChildren" << self.model.rowCount(index)
-                    self.checkChildren(index, depth+1)
-                #else:
+                    # qDebug() << row << column << "hasChildren" <<
+                    # self.model.rowCount(index)
+                    self.checkChildren(index, depth + 1)
+                # else:
                 #   if depth >= 10:
                 #       qDebug() << "checked 10 deep"
 
-                # Make sure that after testing the children that the index doesn't change
+                # Make sure that after testing the children that the index
+                # doesn't change
                 newIdx = self.model.index(row, column, parent)
                 assert(index == newIdx)
