@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+    Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
     partially based on C++ code from:
     Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
@@ -20,32 +20,34 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from qt import Qt, usingQt5, QVariant, variantValue, QSize
+from qt import Qt, QSize
 from qt import QWidget, QHBoxLayout, QVBoxLayout, \
     QPushButton, QSpacerItem, QSizePolicy, \
     QTreeView, QFont, QAbstractItemView, QHeaderView
 from qt import QModelIndex
-from rule import Ruleset, PredefinedRuleset, RuleBase, ParameterRule, \
-    IntRule, BoolRule, StrRule
+from rule import Ruleset, PredefinedRuleset, RuleBase, ParameterRule, BoolRule
 from util import uniqueList
-from log import m18n, m18nc
+from mi18n import i18n, i18nc, i18ncE, english
 from differ import RulesetDiffer
-from common import Debug, english
+from common import Debug, Internal
 from tree import TreeItem, RootItem, TreeModel
-from kde import KApplication
 from dialogs import Sorry
 from modeltest import ModelTest
-from genericdelegates import RightAlignedCheckboxDelegate
+from genericdelegates import RightAlignedCheckboxDelegate, ZeroEmptyColumnDelegate
 from statesaver import StateSaver
 from guiutil import decorateWindow
 
+
 class RuleRootItem(RootItem):
+
     """the root item for the ruleset tree"""
 
     def columnCount(self):
         return len(self.rawContent)
 
+
 class RuleTreeItem(TreeItem):
+
     """generic class for items in our rule tree"""
     # pylint: disable=abstract-method
     # we know content() is abstract, this class is too
@@ -53,7 +55,7 @@ class RuleTreeItem(TreeItem):
     def columnCount(self):
         """can be different for every rule"""
         if hasattr(self, 'colCount'):
-            return self.colCount # pylint: disable=no-member
+            return self.colCount  # pylint: disable=no-member
         else:
             return len(self.rawContent)
 
@@ -64,15 +66,18 @@ class RuleTreeItem(TreeItem):
             item = item.parent
         return item.rawContent
 
+
 class RulesetItem(RuleTreeItem):
+
     """represents a ruleset in the tree"""
+
     def __init__(self, content):
         RuleTreeItem.__init__(self, content)
 
     def content(self, column):
         """return content stored in this item"""
         if column == 0:
-            return m18n(self.rawContent.name)
+            return self.rawContent.name
         return ''
 
     def columnCount(self):
@@ -86,34 +91,40 @@ class RulesetItem(RuleTreeItem):
         """the tooltip for a ruleset"""
         return self.rawContent.description
 
+
 class RuleListItem(RuleTreeItem):
+
     """represents a list of rules in the tree"""
+
     def __init__(self, content):
         RuleTreeItem.__init__(self, content)
 
     def content(self, column):
         """return content stored in this item"""
         if column == 0:
-            return m18n(self.rawContent.name)
+            return self.rawContent.name
         return ''
 
     def tooltip(self):
         """tooltip for a list item explaining the usage of this list"""
         ruleset = self.ruleset()
-        return '<b>' + m18n(ruleset.name) + '</b><br><br>' + \
-            m18n(self.rawContent.description)
+        return '<b>' + i18n(ruleset.name) + '</b><br><br>' + \
+            i18n(self.rawContent.description)
+
 
 class RuleItem(RuleTreeItem):
+
     """represents a rule in the tree"""
+
     def __init__(self, content):
         RuleTreeItem.__init__(self, content)
 
     def content(self, column):
         """return the content stored in this node"""
-        colNames = [unicode(x.toString()) for x in self.parent.parent.parent.rawContent]
+        colNames = self.parent.parent.parent.rawContent
         content = self.rawContent
         if column == 0:
-            return m18n(content.name)
+            return content.name
         else:
             if isinstance(content, ParameterRule):
                 if column == 1:
@@ -121,20 +132,23 @@ class RuleItem(RuleTreeItem):
             else:
                 if not hasattr(content.score, str(column)):
                     column = colNames[column]
-                return unicode(getattr(content.score, column))
+                return getattr(content.score, column)
         return ''
 
     def tooltip(self):
         """tooltip for rule: just the name of the ruleset"""
         ruleset = self.ruleset()
         if self.rawContent.description:
-            return '<b>' + m18n(ruleset.name) + '</b><br><br>' + \
-                m18n(self.rawContent.description)
+            return '<b>' + i18n(ruleset.name) + '</b><br><br>' + \
+                i18n(self.rawContent.description)
         else:
-            return m18n(ruleset.name)
+            return i18n(ruleset.name)
+
 
 class RuleModel(TreeModel):
+
     """a model for our rule table"""
+
     def __init__(self, rulesets, title, parent=None):
         super(RuleModel, self).__init__(parent)
         self.rulesets = rulesets
@@ -146,9 +160,8 @@ class RuleModel(TreeModel):
                 unitNames.extend(rule.score.unitNames.items())
         unitNames = sorted(unitNames, key=lambda x: x[1])
         unitNames = uniqueList(x[0] for x in unitNames)
-        rootData = [QVariant(title)]
-        for unitName in unitNames:
-            rootData.append(QVariant(unitName))
+        rootData = [title]
+        rootData.extend(unitNames)
         self.rootItem = RuleRootItem(rootData)
 
     def canFetchMore(self, dummyParent=None):
@@ -162,43 +175,44 @@ class RuleModel(TreeModel):
             self.appendRuleset(ruleset)
         self.loaded = True
 
-    def data(self, index, role): # pylint: disable=no-self-use
+    def data(self, index, role):  # pylint: disable=no-self-use
         """get data fom model"""
-        # pylint: disable=too-many-branches
+        # pylint: disable=too-many-branches,redefined-variable-type
         # too many branches
-        result = QVariant()
+        result = None
         if index.isValid():
             item = index.internalPointer()
             if role in (Qt.DisplayRole, Qt.EditRole):
                 if index.column() == 1:
                     if isinstance(item, RuleItem) and isinstance(item.rawContent, BoolRule):
-                        return QVariant('')
+                        return ''
                 showValue = item.content(index.column())
-                if isinstance(showValue, basestring) and showValue.endswith('.0'):
+                if isinstance(showValue, str) and showValue.endswith('.0'):
                     try:
                         showValue = str(int(float(showValue)))
                     except ValueError:
                         pass
                 if showValue == '0':
                     showValue = ''
-                result = QVariant(showValue)
+                result = showValue
             elif role == Qt.CheckStateRole:
                 if self.isCheckboxCell(index):
                     bData = item.content(index.column())
-                    result = QVariant(Qt.Checked if bData else Qt.Unchecked)
+                    result = Qt.Checked if bData else Qt.Unchecked
             elif role == Qt.TextAlignmentRole:
-                result = QVariant(int(Qt.AlignLeft|Qt.AlignVCenter))
+                result = int(Qt.AlignLeft | Qt.AlignVCenter)
                 if index.column() > 0:
-                    result = QVariant(int(Qt.AlignRight|Qt.AlignVCenter))
+                    result = int(Qt.AlignRight | Qt.AlignVCenter)
             elif role == Qt.FontRole and index.column() == 0:
                 ruleset = item.ruleset()
                 if isinstance(ruleset, PredefinedRuleset):
                     font = QFont()
                     font.setItalic(True)
-                    result = QVariant(font)
+                    result = font
             elif role == Qt.ToolTipRole:
-                tip = '<b></b>%s<b></b>' % m18n(item.tooltip()) if item else ''
-                result = QVariant(tip)
+                tip = '<b></b>%s<b></b>' % i18n(
+                    item.tooltip()) if item else ''
+                result = tip
         return result
 
     @staticmethod
@@ -216,16 +230,15 @@ class RuleModel(TreeModel):
             return
         if role == Qt.DisplayRole and orientation == Qt.Horizontal:
             if section >= self.rootItem.columnCount():
-                return QVariant()
-            result = variantValue(self.rootItem.content(section))
+                return
+            result = self.rootItem.content(section)
             if result == 'doubles':
-                result = 'x2'
-            return m18n(result)
+                return 'x2'
+            else:
+                return i18nc('kajongg', result)
         elif role == Qt.TextAlignmentRole:
             leftRight = Qt.AlignLeft if section == 0 else Qt.AlignRight
-            return QVariant(int(leftRight|Qt.AlignVCenter))
-        else:
-            return QVariant()
+            return int(leftRight | Qt.AlignVCenter)
 
     def appendRuleset(self, ruleset):
         """append ruleset to the model"""
@@ -244,11 +257,15 @@ class RuleModel(TreeModel):
         self.insertRows(0, ruleListItems, rulesetIndex)
         for ridx, ruleList in enumerate(ruleLists):
             listIndex = self.index(ridx, 0, rulesetIndex)
-            ruleItems = list([RuleItem(x) for x in ruleList if not 'internal' in x.options])
+            ruleItems = list([RuleItem(x)
+                              for x in ruleList if 'internal' not in x.options])
             self.insertRows(0, ruleItems, listIndex)
 
+
 class EditableRuleModel(RuleModel):
+
     """add methods needed for editing"""
+
     def __init__(self, rulesets, title, parent=None):
         RuleModel.__init__(self, rulesets, title, parent)
 
@@ -256,32 +273,23 @@ class EditableRuleModel(RuleModel):
         """change rule data in the model"""
         dirty, message = False, None
         if column == 0:
-            name = unicode(value.toString())
-            if content.name != english(name):
+            if content.name != english(value):
                 dirty = True
-                content.name = english(name)
+                content.name = english(value)
         elif column == 1 and isinstance(content, ParameterRule):
             oldParameter = content.parameter
-            if isinstance(content, IntRule):
-                if content.parameter != value.toInt()[0]:
-                    dirty = True
-                    content.parameter = value.toInt()[0]
-            elif isinstance(content, BoolRule):
+            if isinstance(content, BoolRule):
                 return False, ''
-            elif isinstance(content, StrRule):
-                if content.parameter != unicode(value.toString()):
-                    dirty = True
-                    content.parameter = unicode(value.toString())
             else:
-                if content.parameter != unicode(value.toString()):
+                if content.parameter != value:
                     dirty = True
-                    content.parameter = unicode(value.toString())
+                    content.parameter = value
             message = content.validate()
             if message:
                 content.parameter = oldParameter
                 dirty = False
         else:
-            unitName = str(self.rootItem.content(column).toString())
+            unitName = self.rootItem.content(column)
             dirty, message = content.score.change(unitName, value)
         return dirty, message
 
@@ -298,9 +306,8 @@ class EditableRuleModel(RuleModel):
             content = item.rawContent
             if role == Qt.EditRole:
                 if isinstance(content, Ruleset) and column == 0:
-                    name = unicode(value.toString())
                     oldName = content.name
-                    content.rename(english(name))
+                    content.rename(english(value))
                     dirty = oldName != content.name
                 elif isinstance(content, RuleBase):
                     dirty, message = self.__setRuleData(column, content, value)
@@ -326,7 +333,7 @@ class EditableRuleModel(RuleModel):
         except BaseException:
             return False
 
-    def flags(self, index): # pylint: disable=no-self-use
+    def flags(self, index):  # pylint: disable=no-self-use
         """tell the view what it can do with this item"""
         if not index.isValid():
             return Qt.ItemIsEnabled
@@ -349,9 +356,13 @@ class EditableRuleModel(RuleModel):
             result |= Qt.ItemIsUserCheckable
         return result
 
+
 class RuleTreeView(QTreeView):
+
     """Tree view for our rulesets"""
-    def __init__(self, name, btnCopy=None, btnRemove=None, btnCompare=None, parent=None):
+
+    def __init__(self, name, btnCopy=None,
+                 btnRemove=None, btnCompare=None, parent=None):
         QTreeView.__init__(self, parent)
         self.name = name
         self.setObjectName('RuleTreeView')
@@ -365,10 +376,10 @@ class RuleTreeView(QTreeView):
         self.setSelectionMode(QAbstractItemView.SingleSelection)
         self.ruleModel = None
         self.ruleModelTest = None
-        self.rulesets = [] # nasty: this generates self.ruleModel
+        self.rulesets = []  # nasty: this generates self.ruleModel
         self.differs = []
 
-    def dataChanged(self, dummyIndex1, dummyIndex2):
+    def dataChanged(self, dummyIndex1, dummyIndex2, dummyRoles=None):
         """gets called if the model has changed: Update all differs"""
         for differ in self.differs:
             differ.rulesetChanged()
@@ -385,8 +396,14 @@ class RuleTreeView(QTreeView):
             if self.btnRemove and self.btnCopy:
                 self.ruleModel = EditableRuleModel(rulesets, self.name)
             else:
-                self.ruleModel = RuleModel(rulesets, self.name)
-            self.setItemDelegateForColumn(1, RightAlignedCheckboxDelegate(self, self.ruleModel.isCheckboxCell))
+                self.ruleModel = RuleModel(rulesets, self.name) # pylint: disable=redefined-variable-type
+            self.setItemDelegateForColumn(
+                1,
+                RightAlignedCheckboxDelegate(
+                    self,
+                    self.ruleModel.isCheckboxCell))
+            for  col in (1, 2, 3):
+                self.setItemDelegateForColumn(col, ZeroEmptyColumnDelegate(self))
             self.setModel(self.ruleModel)
             if Debug.modelTest:
                 self.ruleModelTest = ModelTest(self.ruleModel, self)
@@ -400,7 +417,9 @@ class RuleTreeView(QTreeView):
             isPredefined = isinstance(item.ruleset(), PredefinedRuleset)
             if isinstance(item, RulesetItem):
                 enableCompare = True
-                enableCopy = sum(x.hash == item.ruleset().hash for x in self.ruleModel.rulesets) == 1
+                enableCopy = sum(
+                    x.hash == item.ruleset(
+                    ).hash for x in self.ruleModel.rulesets) == 1
                 enableRemove = not isPredefined
         if self.btnCopy:
             self.btnCopy.setEnabled(enableCopy)
@@ -418,14 +437,9 @@ class RuleTreeView(QTreeView):
         header = self.header()
         header.setStretchLastSection(False)
         header.setMinimumSectionSize(-1)
-        if usingQt5:
-            for col in range(1, header.count()):
-                header.setSectionResizeMode(0, QHeaderView.ResizeToContents)
-            header.setSectionResizeMode(0, QHeaderView.Stretch)
-        else:
-            for col in range(1, header.count()):
-                header.setResizeMode(0, QHeaderView.ResizeToContents)
-            header.setResizeMode(0, QHeaderView.Stretch)
+        for col in range(1, header.count()):
+            header.setSectionResizeMode(0, QHeaderView.ResizeToContents)
+        header.setSectionResizeMode(0, QHeaderView.Stretch)
         for col in range(header.count()):
             self.resizeColumnToContents(col)
 
@@ -467,8 +481,11 @@ class RuleTreeView(QTreeView):
         differ.show()
         self.differs.append(differ)
 
+
 class RulesetSelector(QWidget):
+
     """presents all available rulesets with previews"""
+
     def __init__(self, parent=None):
         super(RulesetSelector, self).__init__(parent)
         self.setContentsMargins(0, 0, 0, 0)
@@ -476,7 +493,7 @@ class RulesetSelector(QWidget):
 
     def setupUi(self):
         """layout the window"""
-        decorateWindow(self, m18n('Customize rulesets'))
+        decorateWindow(self, i18n('Customize rulesets'))
         self.setObjectName('Rulesets')
         hlayout = QHBoxLayout(self)
         v1layout = QVBoxLayout()
@@ -492,11 +509,20 @@ class RulesetSelector(QWidget):
         self.btnRemove = QPushButton()
         self.btnCompare = QPushButton()
         self.btnClose = QPushButton()
-        self.rulesetView = RuleTreeView(m18nc('kajongg', 'Rule'), self.btnCopy, self.btnRemove, self.btnCompare)
+        self.rulesetView = RuleTreeView(
+            i18ncE('kajongg',
+                   'Rule'),
+            self.btnCopy,
+            self.btnRemove,
+            self.btnCompare)
         v1layout.addWidget(self.rulesetView)
         self.rulesetView.setWordWrap(True)
         self.rulesetView.setMouseTracking(True)
-        spacerItem = QSpacerItem(20, 20, QSizePolicy.Minimum, QSizePolicy.Expanding)
+        spacerItem = QSpacerItem(
+            20,
+            20,
+            QSizePolicy.Minimum,
+            QSizePolicy.Expanding)
         v2layout.addWidget(self.btnCopy)
         v2layout.addWidget(self.btnRemove)
         v2layout.addWidget(self.btnCompare)
@@ -514,7 +540,7 @@ class RulesetSelector(QWidget):
         """we never want a horizontal scrollbar for player names,
         we always want to see them in full"""
         result = QWidget.sizeHint(self)
-        available = KApplication.kApplication().desktop().availableGeometry()
+        available = Internal.app.desktop().availableGeometry()
         height = max(result.height(), available.height() * 2 // 3)
         width = max(result.width(), available.width() // 2)
         return QSize(width, height)
@@ -542,7 +568,7 @@ class RulesetSelector(QWidget):
 
     def retranslateUi(self):
         """translate to current language"""
-        self.btnCopy.setText(m18n("Copy"))
-        self.btnCompare.setText(m18nc('Kajongg ruleset comparer', 'Compare'))
-        self.btnRemove.setText(m18n("Remove"))
-        self.btnClose.setText(m18n('Close'))
+        self.btnCopy.setText(i18n("C&opy"))
+        self.btnCompare.setText(i18nc('Kajongg ruleset comparer', 'Co&mpare'))
+        self.btnRemove.setText(i18n('&Remove'))
+        self.btnClose.setText(i18n('&Close'))
