@@ -1,8 +1,8 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ from __future__ import print_function
 
 import unittest
 
-from common import Debug, isPython3, unicode  # pylint: disable=unused-import
+from common import Debug  # pylint: disable=unused-import
 from wind import Wind, East, South, West, North
 from player import Players
 from game import PlayingGame
@@ -46,12 +46,12 @@ for _ in RULESETS[2:]:
 Players.createIfUnknown = str
 
 # RULESETS=RULESETS[:1]
-GAMES = list([PlayingGame(list(tuple([wind, unicode(wind.char)]) for wind in Wind.all4), x)
+GAMES = list([PlayingGame(list(tuple([wind, str(wind.char)]) for wind in Wind.all4), x)
               for x in RULESETS])
 PROGRAM = None
 
 
-class Expected(object):
+class Expected:
 
     """define what we expect from test"""
 
@@ -82,7 +82,7 @@ class NoWin(Expected):
         Expected.__init__(self, False, points, doubles, limits)
 
 
-class Helpers(object):
+class Helpers:
 
     """for my test classes"""
     # pylint: disable=no-member, too-many-locals
@@ -122,9 +122,9 @@ class Helpers(object):
                 variant.won == isinstance(exp, Win) and score == exp.score,
                 self.dumpCase(variant, exp, total=None))
 # activate depending on what you are testing
-#            kprint(string, 'expected:', expected.__str__()), variant
-#            kprint(ruleset.name.encode('utf-8'))
-#            kprint('\n'.join(variant.explain).encode('ut-f8'))
+#            print(string, 'expected:', expected.__str__()), variant
+#            print(ruleset.name.encode('utf-8'))
+#            print('\n'.join(variant.explain).encode('ut-f8'))
             if totals:
                 self.assertTrue(score.total() == totals[idx], '\n'.join(
                     self.dumpCase(x, exp, totals[idx]) for x in variants))
@@ -182,10 +182,7 @@ class Helpers(object):
                 'base=%d,doubles=%d,total=%d' %
                 (score.points, score.doubles, hand.total()))
             result.append('')
-        if isPython3:
-            return '\n'.join(result)
-        else:
-            return '\n'.join(x.encode('utf-8') for x in result)
+        return '\n'.join(result)
 
 # pylint: disable=missing-docstring, too-many-public-methods
 
